@@ -89,7 +89,7 @@ Car2goEngine::Car2goEngine(const QString &cacheDir) :
 
 QStringList Car2goEngine::supportedLocations()
 {
-    return QStringList() << "Austin" << "Hamburg" << "Ulm" << "Vancouver";
+    return QStringList() << "Amsterdam" << "Austin" << "Hamburg" << "San Diego" << "Ulm" << "Vancouver" << "Wien";
 }
 
 QList<GMWAccount> Car2goEngine::accounts()
@@ -544,14 +544,20 @@ void Car2goEngine::refreshVehicles(bool useCache)
 
 QGeoBoundingBox Car2goEngine::startingBounds()
 {
-    if (location() == "Austin") {
-        return QGeoBoundingBox(QGeoCoordinate(30.29000,  -97.77000), QGeoCoordinate(30.25000, -97.70000));
+    if(location() == "Amsterdam") {
+        return QGeoBoundingBox(QGeoCoordinate(52.396896, 4.853783), QGeoCoordinate(52.339317, 4.949881));
+    } else if (location() == "Austin") {
+        return QGeoBoundingBox(QGeoCoordinate(30.29000, -97.77000), QGeoCoordinate(30.25000, -97.70000));
     } else if (location() == "Hamburg") {
         return QGeoBoundingBox(QGeoCoordinate(53.72000, 9.84000), QGeoCoordinate(53.41300, 10.15500));
+    } else if(location() == "San Diego") {
+        return QGeoBoundingBox(QGeoCoordinate(32.80715, -117.250194), QGeoCoordinate(32.707689, -117.117355));
     } else if (location() == "Ulm") {
         return QGeoBoundingBox(QGeoCoordinate(48.41000, 9.96000), QGeoCoordinate(48.39000, 10.00000));
     } else if(location() == "Vancouver") {
         return QGeoBoundingBox(QGeoCoordinate(49.314789, -123.237269), QGeoCoordinate(49.230886, -123.062995));
+    } else if(location() == "Wien") {
+        return QGeoBoundingBox(QGeoCoordinate(48.303924, 16.240785), QGeoCoordinate(48.133475, 16.532411));
     } else {
         return QGeoBoundingBox();
     }
